@@ -16,7 +16,7 @@ def create_or_update_action_type(name=None, using=None, apps=None, **options):
     opts = {}
     action_type_model_cls = apps.get_model(action_type_model)
     if options:
-        fields = [f.name for f in action_type_model_cls._meta.fields if f.name != "name"]
+        fields = [f.name for f in action_type_model_cls._meta.get_fields() if f.name != "name"]
         for attr, value in options.items():
             if attr in fields:
                 opts.update({attr: value})
