@@ -5,4 +5,4 @@ action_fields = (
     "related_action_item",
 )
 
-action_fieldset_tuple = ["Action", {"classes": ("collapse",), "fields": action_fields}]
+action_fieldset_tuple = ("Action", {"classes": ("collapse",), "fields": action_fields})
